<?php
/**
* File: class.Config.php
*
* Purpose: A central place holding configurable parameters.
*
* @package napGen
* @subpackage APP_LIB
* @filesource
* @author <a href="mailto:boniface.lau@gmail.com">Boniface Lau</a>
*/

/**
* Class: Config
*
* Purpose: A central place holding configurable parameters.
*
* @package napGen
* @subpackage APP_LIB
* @filesource
* @author <a href="mailto:boniface.lau@gmail.com">Boniface Lau</a>
*/
class Config {

    /**
    * Name of the htdocs top level folder for NapGen to output the
    * generated XML files.
    *
    * NOTE: Whatever folder being pointed to must be properly
    *       configured. See NapGen’s installation notes on how the
    *       folder "napGen_output" was configured.
    */
    const S_XML_FILES_FOLDER = "napGen_output";

    /**
    * URL to the collection of XML Schema Documents that defines NAP.
    *
    * NOTE: This URL is used only during XML validation. It has no
    *       impact on NAP element mapping.
    */
    const S_NAP_SCHEMA_URL =
        "http://nap.geogratis.gc.ca/metadata/tools/schemas/metadata/can-cgsb-171.100-2009-a/";

    /**
    * URL to the master listing of the NAP code lists. If the existing
    * URL stops working, try the following:
    *     http://www.fgdc.gov/nap/metadata/register/codelists.html
    *     http://www.geoconnections.org/nap/metadata/register/codelists.html
    *
    * NOTE: This URL is used only in the generated XML. It has no
    *       impact on the codelists used in NAP element mapping.
    */
    const S_NAP_REG_CODE_LIST_URL =
        "http://nap.geogratis.gc.ca/metadata/register/codelists-eng.html";

    /**
    * URL to the particular item in a NAP code list. If the current
    * URL stops working, try the following:
    *     http://www.fgdc.gov/nap/metadata/register/registerItems.html
    *     http://www.geoconnections.org/nap/metadata/register/registerItems.html
    *
    * NOTE: This URL is used only in the generated XML. It has no
    *       impact on the codelist values used in NAP element mapping.
    */
    const S_NAP_REG_ITEM_URL =
        "http://nap.geogratis.gc.ca/metadata/register/registerItems-eng.html";

    /**
    * The list of namespaces in the default NAP schema that can be
    * overridden by the XML validator to point to a different schema.
    *
    * NOTE: The XSD file locations specified here must be applicable
    *       to both the default NAP schema and the schema that will be
    *       used to override it.
    */
    static public $aCanOverrideNsDir =
        array(# Namespace
              "http://www.geoconnections.org/nap/metadata/Tools/napXsd/napm" =>
                  # Namespace's XSD file location.
                  "napm/napm.xsd",
              "http://www.isotc211.org/2005/gco" => "gco/gco.xsd",
              "http://www.isotc211.org/2005/gmd" => "gmd/gmd.xsd",
              "http://www.isotc211.org/2005/gmx" => "gmx/gmx.xsd",
              "http://www.isotc211.org/2005/gsr" => "gsr/gsr.xsd",
              "http://www.isotc211.org/2005/gss" => "gss/gss.xsd",
              "http://www.isotc211.org/2005/gts" => "gts/gts.xsd",
              "http://www.isotc211.org/schemas/2005/srv" => "srv/srv.xsd",
              "http://www.opengis.net/gml" => "gml/gml.xsd",
              "http://www.w3.org/1999/xlink" => "xlink/xlinks.xsd");
}
